==> infrastructure-base-0.2.7-RELEASE-sources.jar: com/rocogz/syy/infrastructure/entity/app/config/BasicWxMiniAppConfig.java <==
package com.rocogz.syy.infrastructure.entity.app.config;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;
import lombok.experimental.Accessors;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 基础服务-小程序配置信息表
 * </p>
 *
 * @author luoyc
 * @since 2020-12-29
 */
@Data
@Accessors(chain = true)
@TableName("basic_wx_mini_app_config")
public class BasicWxMiniAppConfig extends IdEntity {

    private static final long serialVersionUID=1L;

    /**
     * 服务平台编码
     */
    private String servicePlatformCode;

    /**
     * 服务平台名称
     */
    private String servicePlatformName;

    /**
     * 【代理人】端开启情况
     */
    private String bizStatus;

    /**
     * 平台状态
     */
    private String status;

    /**
     * 备注
     */
    private String remark;

    /**
     * 平台类型
     */
    private String servicePlatformType;

    /**
     * mini_appid
     */
    private String miniAppid;

    /**
     * 小程序名称
     */
    private String appName;

    /**
     * 密钥
     */
    private String secret;

    /**
     * token
     */
    private String token;

    /**
     * aesKey
     */
    private String aesKey;

    /**
     * 消息数据格式
     */
    private String msgDataFormat;

    /**
     * 缓存位置: local、redis，默认local
     */
    private String location;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 创建人
     */
    private String createUser;

    /**
     * 更新人
     */
    private String updateUser;

    /**
     * 归属类型
     */
    private String belongType;

    /**
     * 合作客户编号
     */
    private String customerCode;

    /**
     * 合作客户简称
     */
    @TableField(exist = false)
    private String customerName;

    @TableField(exist = false)
    private Integer page = 1;

    @TableField(exist = false)
    private Integer size = 10;

    /** 查询过滤需要的小程序 appid 列表，没有不过不过滤 */
    @TableField(exist = false)
    private List<String> appids;
}

==> infrastructure-base-0.3.3-RELEASE-sources.jar: com/rocogz/syy/infrastructure/entity/app/config/BasicWxMiniAppConfig.java <==
package com.rocogz.syy.infrastructure.entity.app.config;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;
import lombok.experimental.Accessors;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 基础服务-小程序配置信息表
 * </p>
 *
 * @author luoyc
 * @since 2020-12-29
 */
@Data
@Accessors(chain = true)
@TableName("basic_wx_mini_app_config")
public class BasicWxMiniAppConfig extends IdEntity {

    private static final long serialVersionUID=1L;

    /**
     * 服务平台编码
     */
    private String servicePlatformCode;

    /**
     * 服务平台名称
     */
    private String servicePlatformName;

    /**
     * 【代理人】端开启情况
     */
    private String bizStatus;

    /**
     * 平台状态
     */
    private String status;

    /**
     * 备注
     */
    private String remark;

    /**
     * 平台类型
     */
    private String servicePlatformType;

    /**
     * mini_appid
     */
    private String miniAppid;

    /**
     * 小程序名称
     */
    private String appName;

    /**
     * 密钥
     */
    private String secret;

    /**
     * token
     */
    private String token;

    /**
     * aesKey
     */
    private String aesKey;

    /**
     * 消息数据格式
     */
    private String msgDataFormat;

    /**
     * 缓存位置: local、redis，默认local
     */
    private String location;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 创建人
     */
    private String createUser;

    /**
     * 更新人
     */
    private String updateUser;

    /**
     * 归属类型
     */
    private String belongType;

    /**
     * 合作客户编号
     */
    private String customerCode;

    /**
     * 合作客户简称
     */
    @TableField(exist = false)
    private String customerName;

    @TableField(exist = false)
    private Integer page = 1;

    @TableField(exist = false)
    private Integer limit = 10;

    /** 查询过滤需要的小程序 appid 列表，没有不过不过滤 */
    @TableField(exist = false)
    private List<String> appids;

    /** 需要过滤的数据列表串 */
    @TableField(exist = false)
    private String filterListStr;

    /** 需要过滤的数据类型 */
    @TableField(exist = false)
    private String systemRunType;
}
